/**
 * chartjs-chart-wordcloud
 * https://github.com/sgratzl/chartjs-chart-wordcloud
 *
 * Copyright (c) 2019-2023 Samuel Gratzl <sam@sgratzl.com>
 */

import { ChartType, ScriptableAndArrayOptions, ScriptableContext, FontSpec, Element, VisualElement, CoreChartOptions, CartesianScaleTypeRegistry, DatasetController, ControllerDatasetOptions, CommonHoverOptions, AnimationOptions, Chart, ChartItem, ChartConfiguration } from 'chart.js';

interface IWordElementOptions extends FontSpec, Record<string, unknown> {
    color: string;
    strokeStyle: string;
    rotate: number;
    rotationSteps: number;
    minRotation: number;
    maxRotation: number;
    padding: number;
}
interface IWordElementHoverOptions {
    hoverColor: string;
    hoverSize: FontSpec['size'];
    hoverStyle: FontSpec['style'];
    hoverWeight: FontSpec['weight'];
    hoverStrokeStyle: string;
}
interface IWordElementProps {
    x: number;
    y: number;
    width: number;
    height: number;
    scale: number;
    text: string;
}
declare class WordElement extends Element<IWordElementProps, IWordElementOptions> implements VisualElement {
}
declare module 'chart.js' {
    interface ElementOptionsByType<TType extends ChartType> {
        word: ScriptableAndArrayOptions<IWordElementOptions & IWordElementHoverOptions, ScriptableContext<TType>>;
    }
}

declare class WordCloudController extends DatasetController<'wordCloud', WordElement> {
    private readonly wordLayout;
}
interface IWordCloudControllerDatasetOptions extends ControllerDatasetOptions, ScriptableAndArrayOptions<IWordElementOptions, ScriptableContext<'wordCloud'>>, ScriptableAndArrayOptions<CommonHoverOptions, ScriptableContext<'wordCloud'>>, AnimationOptions<'wordCloud'> {
    fit: boolean;
}
declare module 'chart.js' {
    interface ChartTypeRegistry {
        wordCloud: {
            chartOptions: CoreChartOptions<'wordCloud'>;
            datasetOptions: IWordCloudControllerDatasetOptions;
            defaultDataPoint: number;
            metaExtensions: Record<string, never>;
            parsedDataType: {
                x: number;
            };
            scales: keyof CartesianScaleTypeRegistry;
        };
    }
}
declare class WordCloudChart<DATA extends unknown[] = number[], LABEL = string> extends Chart<'wordCloud', DATA, LABEL> {
    static id: string;
    constructor(item: ChartItem, config: Omit<ChartConfiguration<'wordCloud', DATA, LABEL>, 'type'>);
}

export { IWordCloudControllerDatasetOptions, IWordElementHoverOptions, IWordElementOptions, IWordElementProps, WordCloudChart, WordCloudController, WordElement };
//# sourceMappingURL=index.d.ts.map
